# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector_v2.models.goal_interactions_summary import GoalInteractionsSummary

class TestGoalInteractionsSummary(unittest.TestCase):
    """GoalInteractionsSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoalInteractionsSummary:
        """Test GoalInteractionsSummary
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoalInteractionsSummary`
        """
        model = GoalInteractionsSummary()
        if include_optional:
            return GoalInteractionsSummary(
                is_available = True,
                last_engagement_at = 56,
                last_opt_out_at = 56,
                recent_interaction_count = 56,
                total_interaction_count = 56
            )
        else:
            return GoalInteractionsSummary(
        )
        """

    def testGoalInteractionsSummary(self):
        """Test GoalInteractionsSummary"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
